import { __decorate, __metadata, __param } from "tslib";
import { inject, injectable, optional } from 'inversify';
import { DEPENDENCIES } from '../container/container.const';
import { RequestError } from './errors/request.error';
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
var FetchHttpClient = /** @class */ (function () {
    function FetchHttpClient(cache) {
        this.cache = cache;
        this.requestsAbortControllers = {};
    }
    FetchHttpClient.prototype.get = function (endpoint, params, _a) {
        if (params === void 0) { params = {}; }
        var _b = _a === void 0 ? {} : _a, _c = _b.requestId, requestId = _c === void 0 ? endpoint : _c, _d = _b.headers, headers = _d === void 0 ? {} : _d, _e = _b.ttlInMinutes, ttlInMinutes = _e === void 0 ? 0 : _e;
        this.cancelPreviousRequest(requestId);
        var url = this.buildUrl(endpoint, params);
        var requestOptions = this.getRequestOptions(requestId, headers);
        var cachedResponse = this.cache && this.cache.getItem(url);
        return cachedResponse
            ? Promise.resolve(cachedResponse)
            : fetch(url, requestOptions)
                .then(this.parseResponse)
                .then(this.storeInCache(url, ttlInMinutes));
    };
    FetchHttpClient.prototype.parseResponse = function (response) {
        if (response.ok) {
            return response.json();
        }
        else {
            throw new RequestError('Request failed', response);
        }
    };
    FetchHttpClient.prototype.buildUrl = function (endpoint, params) {
        var url = new URL(endpoint);
        Object.entries(params).forEach(function (_a) {
            var key = _a[0], param = _a[1];
            if (param !== undefined) {
                if (Array.isArray(param)) {
                    param.forEach(function (arrayParamValue) { return url.searchParams.append(key, arrayParamValue); });
                }
                else {
                    url.searchParams.set(key, param);
                }
            }
        });
        return url.href;
    };
    FetchHttpClient.prototype.cancelPreviousRequest = function (requestId) {
        var previousRequest = this.requestsAbortControllers[requestId];
        if (previousRequest) {
            previousRequest.abort();
        }
    };
    FetchHttpClient.prototype.getRequestOptions = function (requestId, headers) {
        if (typeof AbortController !== 'undefined') {
            var signal = this.createAbortController(requestId);
            return { signal: signal, headers: headers };
        }
        return { headers: headers };
    };
    FetchHttpClient.prototype.createAbortController = function (requestId) {
        var controller = new AbortController();
        this.requestsAbortControllers[requestId] = controller;
        return controller.signal;
    };
    FetchHttpClient.prototype.storeInCache = function (url, ttlInMinutes) {
        var _this = this;
        return function (response) {
            if (_this.cache && ttlInMinutes) {
                _this.cache.setItem(url, response, ttlInMinutes);
            }
            return response;
        };
    };
    FetchHttpClient = __decorate([
        injectable(),
        __param(0, optional()),
        __param(0, inject(DEPENDENCIES.cacheService)),
        __metadata("design:paramtypes", [Object])
    ], FetchHttpClient);
    return FetchHttpClient;
}());
export { FetchHttpClient };
//# sourceMappingURL=fetch-http-client.js.map