import { ConfigChangedListener, Dictionary, RequestOptions } from '../types';
import { EmpathyAdapterConfig } from './config/empathy-adapter-config.types';
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export interface Requestor<RequestType = any, ResponseType = any> {
    request(params: RequestType, requestOptions?: RequestOptions): Promise<ResponseType>;
}
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export interface Mapper<From = any, To = any, Context = any> {
    map(from: From, to: To, context: Context): To;
}
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export interface ResponseMapper<From = any, To = any> extends Mapper<From, To, Readonly<ResponseMapperContext>> {
}
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export interface RequestMapper<From = any, To = any> extends Mapper<From, To, Readonly<RequestMapperContext>> {
}
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export interface RequestMapperContext {
    readonly requestOptions: RequestOptions;
    readonly feature: string;
    readonly url: string;
    [key: string]: any;
}
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export interface ResponseMapperContext<RequestType = any, RawResponseType = any> extends RequestMapperContext {
    readonly rawRequest: Readonly<RequestType>;
    readonly rawResponse: Readonly<RawResponseType>;
    readonly request: Dictionary<any>;
}
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export declare type MapFn<From = any, To = any, Context = any> = Mapper<From, To, Context>['map'];
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export declare type MapRequest<From = any, To = any> = MapFn<From, To, RequestMapperContext>;
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export declare type MapResponse<From = any, To = any> = MapFn<From, To, ResponseMapperContext>;
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export declare type BeforeRequest<RawRequestType = any> = (context: BeforeRequestContext<RawRequestType>) => void;
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export declare type BeforeResponseTransform<RawResponseType = any> = (context: BeforeResponseTransformContext<RawResponseType>) => void;
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export declare type ResponseTransformed<RawResponseType = any, ResponseType = any> = (context: ResponseTransformedContext<RawResponseType, ResponseType>) => void;
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export interface BeforeRequestContext<RawRequestType = any> {
    readonly requestOptions: RequestOptions;
    readonly feature: string;
    rawRequest: RawRequestType;
    request: Dictionary<string>;
    url: string;
    [key: string]: any;
}
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export interface BeforeResponseTransformContext<RawResponseType = any> extends BeforeRequestContext {
    rawResponse: RawResponseType;
}
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export interface ResponseTransformedContext<RawResponseType = any, ResponseType = any> extends BeforeResponseTransformContext<RawResponseType> {
    response: ResponseType;
}
/**
 * TODO https://searchbroker.atlassian.net/browse/EX-2163
 *
 * @public
 */
export declare type EmpathyAdapterConfigChangedListener = ConfigChangedListener<EmpathyAdapterConfig>;
